Automation of maintenance jobs with cron — Askbot 0.12.7 documentation

# Askbot Project Documentation

Home | Ask Questions | Consulting Services | Documentation | Contribute | Contact

# Automation of maintenance jobs with cron

There are routine tasks that should be performed periodically from the command line. They can be automated via cron jobs

File askbot_cron_job has a sample script that can be run say hourly

The script currently does two things: (1) sends delayed email alerts and (2) awards badges. These two actions can be separated into two separate jobs, if necessary